name = "scanapi"
from scanapi.__main__ import main

__all__ = ["main"]
